# HTML from Epub

Extract html library from .epub file.

## Install

``` bash
$ pip install html_from_epub
```

## Use

Command line tool script will install along with Python package.

``` bash
$ html-from-epub path_to_file.epub
```

Use in code:

``` python
>>> from html_from_epub import convert
>>> convert('path_to_file.epub')
```

## Contribute

Go ahead:

``` bash
$ git clone https://github.com/casperlehmann/html_from_epub.git
$ cd html_from_epub
$ pip install -r requirements.txt
```
